npbrain.neurons package
=======================

.. currentmodule:: npbrain.neurons
.. automodule:: npbrain.neurons


.. autosummary::
    :toctree: _autosummary

    HH
    Izhikevich
    LIF
    FreqInput
    TimeInput
